const canvas = document.getElementById('gameCanvas');
const ctx = canvas.getContext('2d');

// Game settings
const playerWidth = 50;
const playerHeight = 50;
const blockWidth = 50;
const blockHeight = 50;
const gameWidth = canvas.width;
const gameHeight = canvas.height;
const bulletWidth = 5;
const bulletHeight = 10;

let player = {
    x: gameWidth / 2 - playerWidth / 2,
    y: gameHeight - playerHeight - 10,
    width: playerWidth,
    height: playerHeight,
    speed: 5,
    dx: 0,
    image: new Image()
};

let blockImage = new Image();  
let background1 = new Image();  
let background2 = new Image();  
let backgroundImage = new Image();  

let blocks = [];
let bullets = [];
let score = 0;
let level = 1;
let gameOver = false;
let timer = 10; 
let blockFallSpeed = 3; 
let maxBlocks = 1; // Decreased number of blocks in Level 2
let blockSpawnDelay = 0; 

// Load the images
player.image.src = 'fighter2.png';  
blockImage.src = 'ban.png';  
background1.src = 'space.png';  
background2.src = 'space2.png';  
backgroundImage = background1;  

// Load sound effects
const shootSound = new Audio('bgg.wav');
const hitSound = new Audio('shoot.wav');
const gameOverSound = new Audio('gm.wav');
const background1Sound = new Audio('bgg.wav');
// Handle key events
document.addEventListener('keydown', (e) => {
    if (e.key === 'ArrowLeft' || e.key === 'a') {
        player.dx = -player.speed;
    } else if (e.key === 'ArrowRight' || e.key === 'd') {
        player.dx = player.speed;
    } else if (e.key === ' ' || e.key === 'Enter') {
        if (gameOver) {
            restartGame(); 
        } else {
            shootBullet();
            shootSound.play();
        }
    }
});

document.addEventListener('keyup', () => {
    player.dx = 0;
});

// **Create Falling Blocks (With Delays in Level 2)**
function createBlock() {
    if (blocks.length < maxBlocks) {
        let randomX = Math.random() * (gameWidth - blockWidth);
        let randomDelay = Math.random() * 1200 + 800; // Random delay (800ms - 2000ms)

        setTimeout(() => {
            if (blocks.length < maxBlocks) { 
                blocks.push({
                    x: randomX,
                    y: 0,
                    width: blockWidth,
                    height: blockHeight,
                    speed: blockFallSpeed
                });
            }
        }, level === 2 ? randomDelay : 0);  
    }
}

// Function to shoot a bullet
function shootBullet() {
    bullets.push({
        x: player.x + player.width / 2 - bulletWidth / 2,
        y: player.y,
        width: bulletWidth,
        height: bulletHeight,
        speed: 4 + level 
    });
}

// Function to update the game elements
function update() {
    if (gameOver) {
        gameOverSound.play(); 

        ctx.clearRect(0, 0, gameWidth, gameHeight);

        ctx.font = "50px Arial";
        ctx.fillStyle = "red";
        ctx.textAlign = "center";
        ctx.fillText("GAME OVER", gameWidth / 2, gameHeight / 2);

        document.getElementById('restartBtn').style.display = 'block'; 
        return; 
    }

    // **Draw Background Image**
    ctx.drawImage(backgroundImage, 0, 0, gameWidth, gameHeight);

    // Move player
    player.x += player.dx;

    // Prevent player from going out of bounds
    if (player.x < 0) player.x = 0;
    if (player.x + player.width > gameWidth) player.x = gameWidth - player.width;

    // Move bullets
    for (let i = 0; i < bullets.length; i++) {
        bullets[i].y -= bullets[i].speed;
        if (bullets[i].y < 0) {
            bullets.splice(i, 1);
            i--;
        }
    }

    // Move falling objects
    for (let i = 0; i < blocks.length; i++) {
        let block = blocks[i];
        block.y += block.speed;

        // Check for collision with bullets
        for (let j = 0; j < bullets.length; j++) {
            if (bullets[j].x < block.x + block.width && bullets[j].x + bullets[j].width > block.x &&
                bullets[j].y < block.y + block.height && bullets[j].y + bullets[j].height > block.y) {
                score++;
                blocks.splice(i, 1); 
                bullets.splice(j, 1); 
                hitSound.play(); 
                break;
            }
        }

        // Check for collision with player
        if (block.y + block.height >= player.y &&
            block.x < player.x + player.width &&
            block.x + block.width > player.x) {
            gameOver = true;
        }

        // If block touches the ground
        if (block.y + block.height >= gameHeight) {
            gameOver = true;
        }
    }

    // **Add Blocks Dynamically**
    if (blocks.length < maxBlocks) {
        createBlock();
    }

    // Draw player
    ctx.drawImage(player.image, player.x, player.y, player.width, player.height);

    // Draw bullets
    ctx.fillStyle = 'yellow';
    for (let i = 0; i < bullets.length; i++) {
        ctx.fillRect(bullets[i].x, bullets[i].y, bullets[i].width, bullets[i].height);
    }

    // Draw blocks
    for (let i = 0; i < blocks.length; i++) {
        let block = blocks[i];
        ctx.drawImage(blockImage, block.x, block.y, block.width, block.height);
    }

    // Draw score and level
    ctx.font = '20px Arial';
    ctx.fillStyle = 'white';
    ctx.textAlign = "left";
    ctx.fillText('Score: ' + score, 10, 30);
    ctx.fillText('Level: ' + level, gameWidth - 100, 30);
    ctx.fillText('Time Left: ' + Math.round(timer), gameWidth - 150, 60);

    // Update timer
    if (timer > 0) {
        timer -= 1 / 60;
    }

    // Level Up
    if (timer <= 0 && !gameOver) {
        levelUp();
    }

    requestAnimationFrame(update);
}

// Function to handle level-up logic
function levelUp() {
    if (level === 1) {
        level = 2;
        timer = 10; 
        blockFallSpeed = 4; 
        maxBlocks = 2; // Only 2 blocks at a time (instead of 3)
        blocks = []; 
        backgroundImage = background2; 
        score += 10; 
    }
}

// Start the game
update();
